The audio graph helper functions are renamed now for a better global
visibility and hence references need to be updated in Tegra audio
graph.

Signed-off-by: Sameer Pujar <spu...@nvidia.com>
---
 sound/soc/tegra/tegra_audio_graph_card.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/sound/soc/tegra/tegra_audio_graph_card.c 
b/sound/soc/tegra/tegra_audio_graph_card.c
index 9e43f16..121e572 100644
--- a/sound/soc/tegra/tegra_audio_graph_card.c
+++ b/sound/soc/tegra/tegra_audio_graph_card.c
@@ -184,7 +184,7 @@ static int tegra_audio_graph_card_probe(struct snd_soc_card 
*card)
                return PTR_ERR(priv->clk_plla_out0);
        }
 
-       return graph_card_probe(card);
+       return audio_graph_card_probe(card);
 }
 
 static int tegra_audio_graph_probe(struct platform_device *pdev)
@@ -201,12 +201,12 @@ static int tegra_audio_graph_probe(struct platform_device 
*pdev)
 
        card->probe = tegra_audio_graph_card_probe;
 
        /* graph_parse_of() depends on below */
        card->component_chaining = 1;
        priv->simple.ops = &tegra_audio_graph_ops;
        priv->simple.force_dpcm = 1;
 
-       return graph_parse_of(&priv->simple, dev);
+       return audio_graph_parse_of(&priv->simple, dev);
 }
 
 static const struct tegra_audio_cdata tegra210_data = {
@@ -201,12 +201,12 @@ static int tegra_audio_graph_probe(struct platform_device 
        card->probe = tegra_audio_graph_card_probe;
 
-       /* graph_parse_of() depends on below */
+       /* audio_graph_parse_of() depends on below */
        card->component_chaining = 1;
        priv->simple.ops = &tegra_audio_graph_ops;
-- 
2.7.4

Reply via email to